// 模拟延迟
const delay = (ms: number) => new Promise(resolve => setTimeout(resolve, ms))

// 视频数据接口
export interface Video {
  id: number
  title: string
  url: string
  thumbnail: string
  duration: string
  category: string
  views: number
  description: string
  uploadTime: string
  likes: number
  comments: number
  tags: string[]
}

// 模拟视频数据
const mockVideos: Video[] = [
  {
    id: 1,
    title: '每日健康操',
    url: 'http://clips.vorwaerts-gmbh.de/big_buck_bunny.mp4',
    thumbnail: 'https://peach.blender.org/wp-content/uploads/bbb-splash.png',
    duration: '10:00',
    category: 'health',
    views: 1234,
    description: '适合老年人的健康运动视频',
    uploadTime: '2024-03-20',
    likes: 256,
    comments: 45,
    tags: ['健康', '运动', '教学']
  },
  {
    id: 2,
    title: '养生保健知识讲座',
    url: 'https://media.w3.org/2010/05/sintel/trailer.mp4',
    thumbnail: 'https://durian.blender.org/wp-content/uploads/2010/05/sintel_trailer_1080.jpg',
    duration: '15:30',
    category: 'health',
    views: 2345,
    description: '专业医生讲解养生知识',
    uploadTime: '2024-03-19',
    likes: 342,
    comments: 67,
    tags: ['养生', '健康', '讲座']
  },
  {
    id: 3,
    title: '24式太极拳教学',
    url: 'https://media.w3.org/2010/05/video/movie_300.mp4',
    thumbnail: 'https://img.freepik.com/free-photo/elderly-people-doing-tai-chi_23-2148965375.jpg',
    duration: '45:00',
    category: 'health',
    views: 3456,
    description: '专业老师讲解24式太极拳基本动作要领',
    uploadTime: '2024-03-18',
    likes: 567,
    comments: 89,
    tags: ['太极拳', '运动', '教学']
  },
  {
    id: 4,
    title: '经典戏曲欣赏',
    url: 'https://vjs.zencdn.net/v/oceans.mp4',
    thumbnail: 'https://img.freepik.com/free-photo/chinese-opera-performer_1159-819.jpg',
    duration: '25:00',
    category: 'entertainment',
    views: 4567,
    description: '传统戏曲表演精选',
    uploadTime: '2024-03-17',
    likes: 678,
    comments: 123,
    tags: ['戏曲', '文化', '艺术']
  },
  {
    id: 5,
    title: '广场舞教学',
    url: 'http://clips.vorwaerts-gmbh.de/big_buck_bunny.mp4',
    thumbnail: 'https://img.freepik.com/free-photo/group-elderly-people-dancing_23-2148965384.jpg',
    duration: '30:00',
    category: 'entertainment',
    views: 5678,
    description: '广场舞基础动作教学',
    uploadTime: '2024-03-16',
    likes: 789,
    comments: 234,
    tags: ['广场舞', '运动', '教学']
  }
]

// 视频分类
export const videoCategories = [
  { label: '全部', value: '' },
  { label: '健康讲座', value: 'health' },
  { label: '娱乐节目', value: 'entertainment' },
  { label: '新闻资讯', value: 'news' }
]

// 视频相关接口
export const videoApi = {
  // 获取视频列表
  async getList(params: {
    pageNum?: number
    pageSize?: number
    keyword?: string
  }) {
    const res = await request.get('/videos', { params })
    return res.data
  },

  // 获取视频详情
  async getDetail(id: number) {
    const res = await request.get(`/videos/${id}`)
    return res.data
  },

  // 上传视频
  async upload(data: FormData) {
    const res = await request.post('/videos/upload', data, {
      headers: {
        'Content-Type': 'multipart/form-data'
      }
    })
    return res.data
  },

  // 更新视频信息
  async update(id: number, data: {
    title: string
    description: string
    tags?: string
  }) {
    const res = await request.put(`/videos/${id}`, data)
    return res.data
  },

  // 删除视频
  async delete(id: number) {
    await request.delete(`/videos/${id}`)
  },

  // 点赞/取消点赞
  async toggleLike(id: number) {
    await request.post(`/videos/${id}/like`)
  },

  // 增加观看次数
  async addView(id: number) {
    await request.post(`/videos/${id}/view`)
  },

  // 获取推荐视频
  async getRecommend(limit: number = 10) {
    const res = await request.get('/videos/recommend', {
      params: { limit }
    })
    return res.data
  },

  // 获取相似视频
  async getSimilar(id: number, limit: number = 10) {
    const res = await request.get(`/videos/${id}/similar`, {
      params: { limit }
    })
    return res.data
  }
}

// 视频DTO类型定义
export interface VideoDTO {
  id: number
  title: string
  description: string
  url: string
  coverUrl: string
  duration: number
  size: number
  status: 'DRAFT' | 'PUBLISHED' | 'DELETED'
  userId: number
  username: string
  createdTime: string
  updatedTime: string
  viewCount: number
  likeCount: number
  tags: string
  hasLiked: boolean
}

// 分页响应类型
export interface PageResponse<T> {
  records: T[]
  total: number
  size: number
  current: number
  pages: number
}

// 响应类型
export interface ApiResponse<T> {
  code: number
  message: string
  data: T
} 